@@ -5,13 +5,13 @@ from modules.TOMLSerializerCreator import TomlSerializerCreator
 from modules.YAMLSerializerCreator import YamlSerializerCreator
 
 parser = argparse.ArgumentParser(description='Process converting between formats.')
-parser.add_argument('-source', dest='-source', type=str,
+parser.add_argument('-source', dest='source', type=str,
                     help='source file path')
-parser.add_argument('-source_format', dest='-source_format', type=str,
+parser.add_argument('-source_format', dest='source_format', type=str,
                     help='source format')
-parser.add_argument('-destination', dest='-destination', type=str,
+parser.add_argument('-destination', dest='destination', type=str,
                     help='destination file path')
-parser.add_argument('-format', dest='-format', type=str,
+parser.add_argument('-format', dest='format', type=str,
                     help='new format')
 parser.add_argument('-conf_file', dest="conf_file", type=str,
                     help='configuration file')
@@ -21,10 +21,10 @@ formats = {'JSON': JsonSerializerCreator(), 'YAML': YamlSerializerCreator(), 'TO
 
 def setup():
     args = parser.parse_args()
-    source = None
-    source_format = None
-    destination = None
-    format = None
+    source = args.source
+    source_format = args.source_format
+    destination = args.destination
+    format = args.format
     if args.conf_file is not None and args.conf_file is "config.py":
         config = __import__(args.conf_file)
         flag = False
@@ -52,7 +52,7 @@ def setup():
         if not flag:
             convert(source, source_format, destination, format)
     else:
-        convert(args.source, args.source_format, args.destination, args.format)
+        convert(source, source_format, destination, format)
 
 
 def convert(source, source_format, dest, dest_format):
